AudioFlux class
The main widget which visualizes the audio data.
It can render the waveform, the FFT, or a shader. The waveform and the FFT are implemented as CustomPainters. While the shader is implemented using shader_buffers package.
The audio data can be acquired from flutter_soloud or flutter_recorder using the DataSources enum.
The visualizer kind can be set using the FluxType enum.
The parameters for the waveform, the FFT, or the shader can be set using the ModelParams class.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AudioFlux
Constructors
- AudioFlux({required DataSources dataSource, required FluxType fluxType, required ModelParams modelParams, Key? key})
-
const
Properties
- dataSource → DataSources
-
The source of the audio data.
final
- fluxType → FluxType
-
The type of the visualizer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- modelParams → ModelParams
-
The parameters for the waveform, the FFT, or the shader.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AudioFlux> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited