ShaderParams class
Definition of shader parameters.
Constructors
-
ShaderParams({String shaderName = '', String shaderPath = '', List<
ShaderParam> ? params, List<ShaderParamRange> ? paramsRange, List<TextureChannel> ? textureChannels}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ List<
ShaderParam> ? -
The shader parameters
final
-
paramsRange
→ List<
ShaderParamRange> ? -
The shader parameters that have a range
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shaderName → String
-
The shader name
final
- shaderPath → String
-
The shader path in the
assetsfolderfinal -
textureChannels
→ List<
TextureChannel> ? -
The shader textures
final
Methods
-
copyWith(
{String? shaderName, String? shaderPath, List< ShaderParam> ? params, List<ShaderParamRange> ? paramsRange, List<TextureChannel> ? textureChannels}) → ShaderParams -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited